@@ -3,6 +3,7 @@ from datetime import datetime
 from intstreamsdk.client import Client
 import tldextract
 import logging
+import copy
 
 LOG = logging.getLogger(__name__)
 
@@ -104,6 +105,8 @@ class Resource(object):
         :param filter: dict
         :return:
         """
+        self.params = filter
+        """
         params = "?"
         count = 0
         for key, value in filter.items():
@@ -115,6 +118,7 @@ class Resource(object):
 
         self.request_url = '{current}{params}'.format(current=self.request_url,
                                                    params=params)
+        """
 
     def id(self, id):
         self.request_url = '{current}{id}/'.format(current=self.request_url,
@@ -204,7 +208,8 @@ class Indicator(ResourcePaged):
         :return:
         """
         self.json = [{"value": i} for i in indicators]
-
+    def indicators_put(self, info):
+        self.json = info
 
 class MD5(Indicator):
 
@@ -315,7 +320,7 @@ class DomainExtractor(object):
         :param url:
         """
         self.subdomain, self.domain, self.suffix = tldextract.extract(url)
-        if self.suffix is None and raise_exc:
+        if (self.suffix is None or self.suffix == "") and raise_exc:
             raise NoTLD
         resource = Suffix(client)
         resource.filter(filter={"value":self.suffix})
@@ -344,7 +349,8 @@ class DomainLoader(object):
         :param method: str
         :return: list[dict]
         """
-        net_locs = []
+        new_net_locs = []
+        existing = []
         all_data = []
         for i in self.urls:
             extractor = DomainExtractor(i, self.client,)
@@ -357,14 +363,23 @@ class DomainLoader(object):
             resource_get.filter(filter=filter)
             r = resource_get.full_request()
             if r["status"] == Resource.SUCCESS and r["data"]["count"] == 0:
-                net_locs.append(extractor.net_loc)
+                new_net_locs.append(extractor.net_loc)
             else:
-                all_data.extend(r["data"]["results"])
+                existing.extend(r["data"]["results"])
+                all_data.extend(existing)
+        #if len(existing) > 0:
+        #    # update indicators to kick off indicator jobs on intstream
+        #    for i in copy.deepcopy(existing):
+        #        del i["id"]
+        #        resource = NetLoc(self.client, method=Resource.PUT)
+        #        resource.indicators_put(i)
+        #        res = resource.full_request()
 
-        resource = NetLoc(self.client, method=Resource.POST)
-        resource.indicators_post(net_locs)
-        res = resource.full_request()
-        all_data.extend(res["data"]["results"])
+        if len(new_net_locs) > 0:
+            resource = NetLoc(self.client, method=Resource.POST)
+            resource.indicators_post(new_net_locs)
+            res = resource.full_request()
+            all_data.extend(res["data"]["results"])
         return all_data
 
     def upload(self):
@@ -410,11 +425,14 @@ class IndicatorAction(object):
     def check_upload(self,
                      indicators,
                      resource_class,
+                     update=False
                      ):
         """
         check upload for all indicator types except NetLoc; use DomainLoader instead
         :param indicators:
         :param resource_class:
+        :param update: bool. set to True if you want tasks to run for each indicator
+        whether or not it already exists in the database
         :return:
         """
         resource_get = resource_class(client=self.client, method=Resource.GET)
@@ -431,6 +449,16 @@ class IndicatorAction(object):
             response_post = resource_post.full_request()
             all_data = response_get["data"]["results"]
             all_data.extend(response_post["data"]["results"])
+        if update:
+            if len(existing_obj) > 0:
+                # update indicator to kick off indicator tasks.
+                for i in copy.deepcopy(existing_obj):
+                    resource_put = resource_class(client=self.client, method=Resource.PUT)
+                    resource_put.id(i["id"])
+                    resource_put.indicators_put(i)
+                    response_put = resource_put.full_request()
+                    all_data.extend(response_put["data"])
+
         return all_data
 
 
@@ -472,6 +500,13 @@ class CustomField(Resource):
     def col_value_post(self, name, value, indicator_id):
         self.json = {"name": name, "value": value, "indicator": indicator_id}
 
+    def getIndicatorColumns(self, indicator_id):
+        # retrieve id
+        res_col_get = CustomField(self.client, endpoint=self.endpoint, method=Resource.GET)
+        res_col_get.filter({"indicator": indicator_id})
+        r = res_col_get.full_request()
+        return r["data"]["results"]
+
 
 class IndicatorNumericField(CustomField):
     def __init__(self, client:Client, method=Resource.GET):
@@ -515,6 +550,8 @@ class IndicatorJob(ResourcePaged):
     def __init__(self, client:Client, method=Resource.GET):
         super(IndicatorJob, self).__init__(client, "indicatorjob/", method)
 
+
+
     def job_post(self, name,
                  indicator_type_ids,
                  python_version,
